@@ -91,7 +91,7 @@ Import this package is equivalent to:
 
   use Crane::Base;
   
-  say 'Hello!' or croak($OS_ERROR);
+  say 'Hello!' or confess($OS_ERROR);
 
 
 =head2 Package usage
@@ -108,7 +108,7 @@ Import this package is equivalent to:
   );
   
   sub example {
-      say 'This is an example!' or croak($OS_ERROR);
+      say 'This is an example!' or confess($OS_ERROR);
   }
   
   1;
@@ -118,7 +118,7 @@ Import this package is equivalent to:
 
 =over
 
-=item BASE_PATH
+=item B<BASE_PATH>
 
 Used to determine the base directory for the application environment.
 
@@ -128,8 +128,8 @@ Used to determine the base directory for the application environment.
 =head1 BUGS
 
 Please report any bugs or feature requests to
-L<https://github.com/temoon/crane/issues>. I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Crane> or to
+L<https://github.com/temoon/crane/issues>.
 
 
 =head1 AUTHOR
@@ -150,9 +150,13 @@ license in the file LICENSE.
 
 =over
 
+=item * B<RT Cpan>
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Crane>
+
 =item * B<Github>
 
-https://github.com/temoon/crane
+L<https://github.com/temoon/crane>
 
 =back
 
